Extending ACLs
--------------

Both the description part (:class:`invenio_explicit_acls.models.ACL`)
and actor part (:class:`invenio_explicit_acls.models.Actor`)
are extensible and custom implementation can be provided via inheriting
from these classes.
